const path = require('path')
const TerserPlugin = require('terser-webpack-plugin')

module.exports = {
  entry: {
    'bexpr-parser': './src/index.ts',
    'bexpr-parser.min': './src/index.ts'
  },
  output: {
    path: path.resolve(__dirname, '_bundles'),
    filename: '[name].js',
    libraryTarget: 'umd',
    library: 'BExpr',
    umdNamedDefine: true
  },
  resolve: {
    extensions: ['.ts', '.tsx', '.js']
  },
  devtool: 'source-map',
  optimization: {
    minimizer: [
      new TerserPlugin({
        cache: true,
        parallel: true,
        sourceMap: true,
        include: /\.min\.js$/,
      })
    ]
  },
  module: {
    rules: [{
      test: /\.tsx?$/,
      use: [
        {
          loader: 'awesome-typescript-loader', 
          options: {
            configFileName: 'tsconfig.json',
            query: {
              declaration: false
            }
          }
        }
      ],
      exclude: /node_modules/
    }]
  }
}